var path = require('path');
var _ = require('underscore');
var viewHelpers = require('./src/lib/view-helpers');

module.exports = function(grunt) {
	'use strict';

	// Your stylus file
	var STYLUS_FILES = [
		'src/public/css/reset.styl',
		'src/public/css/main.styl'
	];

	// Your public js files (exclude 3rd party libraries)
	var PUBLIC_JAVASCRIPT_FILES = [
		'src/public/js/main.js'
	];

	// Usually just these two build files
	var PROJECT_FILES = [
		'grunt.js',
		'package.json'
	];

	// Project configuration.
	grunt.initConfig({
		pkg: '<json:package.json>',
		lint: {
			files: [].concat(
				PUBLIC_JAVASCRIPT_FILES,
				PROJECT_FILES
			)
		},
		clean: {
			js: [
				'bin/public/js/**/*.js'
			],
			css: [
				'bin/public/css/**/*.css'
			],
			html: [
				'bin/**/*.html'
			],
			copy: [
				'bin/public/img/**/*',
				'bin/public/fonts/**/*',
				'bin/public/files/**/*'
			]
		},
		stylus: {
			compile: {
				options: {
					compress: true
				},
				files: {
					// Compile and concat into single file.
					'bin/public/css/<%= pkg.name %>-<%= pkg.version %>.css': STYLUS_FILES
				}
			}
		},
		concat: {
			dist: {
				src: [
					'src/public/js/jquery.1.8.3.min.js',
					'src/public/js/main.js'
				],
				dest: 'bin/public/js/<%= pkg.name %>-<%= pkg.version %>.js'
			}
		},
		min: {
			dist: {
				src: [
					'bin/public/js/<%= pkg.name %>-<%= pkg.version %>.js'
				],
				dest: 'bin/public/js/<%= pkg.name %>-<%= pkg.version %>.min.js'
			}
		},
		copy: {
			dist: {
				files: {
					"bin/public/img/": "src/public/img/**/*",
					"bin/public/fonts/": "src/public/fonts/**/*",
					"bin/public/files/": "src/public/files/**/*"
				}
			}
		},
		watch: {
			stylus: {
				files: STYLUS_FILES,
				tasks: 'clean:css stylus'
			},
			jade: {
				files: 'src/views/**/*.jade',
				tasks: 'clean:html jade'
			},
			images: {
				files: 'src/public/img/**/*',
				tasks: 'clean:copy copy'
			},
			fonts: {
				files: 'src/public/fonts/**/*',
				tasks: 'clean:copy copy'
			},
			files: {
				files: 'src/public/files/**/*',
				tasks: 'clean:copy copy'
			},
			publicJavaScript: {
				files: [].concat(
					PUBLIC_JAVASCRIPT_FILES
				),
				tasks: 'lint clean:js concat min'
			},
			serverJavaScript: {
				files: [].concat(
					PROJECT_FILES
				),
				tasks: 'lint'
			}
		},
		jshint: {
			options: {
				smarttabs: true,
				trailing: true,
				curly: true,
				eqeqeq: true,
				immed: true,
				latedef: false,
				newcap: true,
				noarg: true,
				sub: true,
				undef: true,
				boss: true,
				eqnull: true,
				node: true,
				es5: true,
				strict: false
			},
			globals: {
				describe: true,
				it: true,
				before: true,
				after: true,
				exports: true,
				// Browser:
				window: true,
				document: true,
				$: true,
				google: true,
				jQuery: true
			}
		},
		jade: {
			compile: {
				options: {
					data: {
						debug: false,
						// Manually bring in the helpers.
						a: viewHelpers.a,
						strong: viewHelpers.strong,
						title: viewHelpers.title,
						rssDate: viewHelpers.rssDate,
						project: {
							name: '<%= pkg.name %>',
							version: '<%= pkg.version %>',
							js: {
								useMinified: true
							}
						}
					}
				},
				files: {
					"bin/index.html": "src/views/pages/index.jade",
					"bin/contact/index.html": "src/views/pages/contact.jade"
				}
			}
		}
	});

	// Import custom tasks (and override the default test with mocha test).
	grunt.loadNpmTasks('grunt-contrib');
	grunt.loadNpmTasks('grunt-contrib-watch');

	// Default task.
	grunt.registerTask('default', 'lint clean stylus concat min copy jade');
};